@@ -1,4 +1,5 @@
 # -*- coding: utf-8 -*-
+# Copyright 2017 Elisey Zanko
 # Copyright 2016 Étienne Bersac
 # Copyright 2016 Julien Danjou
 # Copyright 2016 Joshua Harlow
@@ -21,13 +22,21 @@ try:
 except ImportError:
     asyncio = None
 
+try:
+    import tornado
+except ImportError:
+    tornado = None
+
 import sys
 import threading
-
 from concurrent import futures
+
 from time import monotonic as now
+
 import six
 
+from tenacity import _utils
+
 # Import all built-in retry strategies for easier usage.
 from .retry import retry_all  # noqa
 from .retry import retry_always  # noqa
@@ -69,8 +78,6 @@ from .before import before_nothing  # noqa
 from .after import after_log  # noqa
 from .after import after_nothing  # noqa
 
-from tenacity import _utils
-
 
 def retry(*dargs, **dkw):
     """Wrap a function with a new `Retrying` object.
@@ -85,6 +92,8 @@ def retry(*dargs, **dkw):
         def wrap(f):
             if asyncio and asyncio.iscoroutinefunction(f):
                 r = AsyncRetrying(*dargs, **dkw)
+            elif tornado and tornado.gen.is_coroutine_function(f):
+                r = TornadoRetrying(*dargs, **dkw)
             else:
                 r = Retrying(*dargs, **dkw)
 
@@ -321,3 +330,6 @@ class RetryError(Exception):
 
 if asyncio:
     from tenacity.async import AsyncRetrying
+
+if tornado:
+    from tenacity.tornadoweb import TornadoRetrying
